Code edit (2 edits merged)
Please save this source code
Code edit (1 edits merged)
Please save this source code
User prompt
increase the animation speed for the enemy_rower
User prompt
enemy_rower needs to have an animation comprised of 2 frames. the second frame is enemy_rower_1. alternate between these frames once every 500 miliseconds
Code edit (3 edits merged)
Please save this source code
User prompt
move the enemy_rower 50 pixels lower
User prompt
attack the asset Enemy_Rower to the Obstacle similar to how you attached the rower to the player. the enemy_rower needs to overlap the obstacle
User prompt
attack the asset Enemy_Rower to the Obstacle similar to how you attached the rower to the player
User prompt
attack the asset Enemy_Rower to the Obstacle
User prompt
I dont see the 2 instances of the enemy_rower attached to the obstacle. this is a bug, attach them to the obstacle
User prompt
attack the asset Enemy_Rower to the Obstacle. but attach 2 of them with a 50 pixels distance between them
Code edit (1 edits merged)
Please save this source code
User prompt
spawn even more coins
Code edit (1 edits merged)
Please save this source code
===================================================================
--- original.js
+++ change.js
@@ -248,9 +248,9 @@
coin.x = 0;
}
// Switch coin spawn direction
coinSpawnDirection = coinSpawnDirection === 'right' ? 'left' : 'right';
-}, 200); // Create a coin every 200 milliseconds
+}, 100); // Create a coin every 100 milliseconds
// Listen for touch events to flip gravity
game.on('down', function () {
if (player.touchingEdge) {
player.flipGravity();